==> tuia-news-center-api-0.0.22-xt2-20180426.012248-1-sources.jar: cn/com/duiba/tuia/news/center/dto/AddActivityDto.java <==
package cn.com.duiba.tuia.news.center.dto;

import java.io.Serializable;

public class AddActivityDto implements Serializable{

    private static final long serialVersionUID = 5806863072704735913L;
    /**
     * 活动名称
     */
    private String activityName;

    /**
     * 活动url
     */
    private String activityUrl;

    /**
     * 活动图片地址
     */
    private String activityImage;

    /**
     * 活动图片(大)地址
     */
    private String  activityBigImage;

    /**
     * 活动来源
     */
    private String activitySource;

    /**
     * 活动类型 1-推啊活动 2- 好晚活动
     */
    private Integer activityType;

    /**
     * 类目
     */
    private String            tip;

    public String getTip() {
        return tip;
    }

    public void setTip(String tip) {
        this.tip = tip;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public String getActivityBigImage() {
        return activityBigImage;
    }

    public void setActivityBigImage(String activityBigImage) {
        this.activityBigImage = activityBigImage;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityUrl() {
        return activityUrl;
    }

    public void setActivityUrl(String activityUrl) {
        this.activityUrl = activityUrl;
    }

    public String getActivityImage() {
        return activityImage;
    }

    public void setActivityImage(String activityImage) {
        this.activityImage = activityImage;
    }

    public String getActivitySource() {
        return activitySource;
    }

    public void setActivitySource(String activitySource) {
        this.activitySource = activitySource;
    }
}

==> tuia-news-center-api-0.0.26-xt15-20180512.072228-1-sources.jar: cn/com/duiba/tuia/news/center/dto/AddActivityDto.java <==
package cn.com.duiba.tuia.news.center.dto;

import java.io.Serializable;

public class AddActivityDto implements Serializable{

    private static final long serialVersionUID = 5806863072704735913L;
    /**
     * 活动名称
     */
    private String activityName;

    /**
     * 活动url
     */
    private String activityUrl;

    /**
     * 活动图片地址
     */
    private String activityImage;

    /**
     * 活动图片(大)地址
     */
    private String  activityBigImage;

    /**
     * 活动来源
     */
    private String activitySource;

    /**
     * 活动类型 1-推啊活动 2- 好晚活动
     */
    private Integer activityType;

    /**
     * 类目
     */
    private String            tip;

    /**
     * 活动Id
     */
    private String   activityId;

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public String getTip() {
        return tip;
    }

    public void setTip(String tip) {
        this.tip = tip;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public String getActivityBigImage() {
        return activityBigImage;
    }

    public void setActivityBigImage(String activityBigImage) {
        this.activityBigImage = activityBigImage;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityUrl() {
        return activityUrl;
    }

    public void setActivityUrl(String activityUrl) {
        this.activityUrl = activityUrl;
    }

    public String getActivityImage() {
        return activityImage;
    }

    public void setActivityImage(String activityImage) {
        this.activityImage = activityImage;
    }

    public String getActivitySource() {
        return activitySource;
    }

    public void setActivitySource(String activitySource) {
        this.activitySource = activitySource;
    }
}
